Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BP ¶
type BP struct {
Get <-chan *bytes.Buffer // Get a buffer from the pool
Give chan<- *bytes.Buffer // Give a buffer to be stored in the pool
Makes int // total buffers allocated
// contains filtered or unexported fields
}
BP includes Get and Give directional channels for retrieving and returning buffers
Click to show internal directories.
Click to hide internal directories.